==> galileo-0.2.0-py3-none-any.whl: galileo/resources/api/trace/get_trace_projects_project_id_traces_trace_id_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.trace_with_metrics import TraceWithMetrics
from ...types import Response


def _get_kwargs(project_id: str, trace_id: str) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {"method": "get", "url": f"/projects/{project_id}/traces/{trace_id}"}

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, TraceWithMetrics]]:
    if response.status_code == 200:
        response_200 = TraceWithMetrics.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, TraceWithMetrics]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, trace_id: str, *, client: AuthenticatedClient
) -> Response[Union[HTTPValidationError, TraceWithMetrics]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, TraceWithMetrics]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, trace_id: str, *, client: AuthenticatedClient
) -> Optional[Union[HTTPValidationError, TraceWithMetrics]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, TraceWithMetrics]
    """

    return sync_detailed(project_id=project_id, trace_id=trace_id, client=client).parsed


async def asyncio_detailed(
    project_id: str, trace_id: str, *, client: AuthenticatedClient
) -> Response[Union[HTTPValidationError, TraceWithMetrics]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, TraceWithMetrics]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, trace_id: str, *, client: AuthenticatedClient
) -> Optional[Union[HTTPValidationError, TraceWithMetrics]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, TraceWithMetrics]
    """

    return (await asyncio_detailed(project_id=project_id, trace_id=trace_id, client=client)).parsed

==> galileo-1.12.0-py3-none-any.whl: galileo/resources/api/trace/get_trace_projects_project_id_traces_trace_id_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.trace_record_with_children import TraceRecordWithChildren
from ...types import Response


def _get_kwargs(project_id: str, trace_id: str) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": RequestMethod.GET,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/traces/{trace_id}",
    }

    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, TraceRecordWithChildren]]:
    if response.status_code == 200:
        response_200 = TraceRecordWithChildren.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, TraceRecordWithChildren]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, trace_id: str, *, client: ApiClient
) -> Response[Union[HTTPValidationError, TraceRecordWithChildren]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, TraceRecordWithChildren]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, trace_id: str, *, client: ApiClient
) -> Optional[Union[HTTPValidationError, TraceRecordWithChildren]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, TraceRecordWithChildren]
    """

    return sync_detailed(project_id=project_id, trace_id=trace_id, client=client).parsed


async def asyncio_detailed(
    project_id: str, trace_id: str, *, client: ApiClient
) -> Response[Union[HTTPValidationError, TraceRecordWithChildren]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, TraceRecordWithChildren]]
    """

    kwargs = _get_kwargs(project_id=project_id, trace_id=trace_id)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, trace_id: str, *, client: ApiClient
) -> Optional[Union[HTTPValidationError, TraceRecordWithChildren]]:
    """Get Trace

    Args:
        project_id (str):
        trace_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, TraceRecordWithChildren]
    """

    return (await asyncio_detailed(project_id=project_id, trace_id=trace_id, client=client)).parsed
